use serde::{Serialize,Deserialize};
pub use microrm::{Entity, model::SchemaModel, query::ID};

#[derive(Entity,Serialize,Deserialize)]
pub struct Realm {
    pub shortname: String
}

#[derive(Entity,Serialize,Deserialize)]
pub struct Key {
    pub realm: ID,
    pub key_id: String,
    #[serde(with = "serde_bytes")]
    pub keydata: Vec<u8>
}

#[derive(Entity,Serialize,Deserialize)]
pub struct User {
    pub realm: ID,
    pub username: String,
}

#[derive(Entity,Serialize,Deserialize)]
pub struct Password {
    pub user: ID,
    pub salt: String,
    pub hash: String
}

#[derive(Entity,Serialize,Deserialize)]
pub struct Group {
    pub realm: ID,
    pub shortname: String,
}

#[derive(Entity,Serialize,Deserialize)]
pub struct Client {
    pub realm: ID,
    pub shortname: String,
    pub secret: String,
}

#[derive(Entity,Serialize,Deserialize)]
pub struct Scope {
    pub realm: ID,
    pub shortname: String,
}

#[derive(Entity,Serialize,Deserialize)]
pub struct Role {
    pub realm: ID,
    pub group: ID,
    pub shortname: String,
}

pub fn schema() -> SchemaModel {
    SchemaModel::new()
        .add::<Realm>()
        .add::<Key>()
        .add::<User>()
        .add::<Password>()
        .add::<Group>()
        .add::<Client>()
        .add::<Scope>()
        .add::<Role>()
}
